import sys
import typing
from . import bvhtree
from . import kdtree
from . import geometry
from . import interpolate
from . import noise


class Color:
    '''This object gives access to Colors in Blender. '''

    b: float = None
    '''Blue color channel. 

    :type: float
    '''

    g: float = None
    '''Green color channel. 

    :type: float
    '''

    h: float = None
    '''HSV Hue component in [0, 1]. 

    :type: float
    '''

    hsv: float = None
    '''HSV Values in [0, 1]. 

    :type: float
    '''

    is_frozen: bool = None
    '''True when this object has been frozen (read-only). 

    :type: bool
    '''

    is_wrapped: bool = None
    '''True when this object wraps external data (read-only). 

    :type: bool
    '''

    owner = None
    '''The item this is wrapping or None (read-only). '''

    r: float = None
    '''Red color channel. 

    :type: float
    '''

    s: float = None
    '''HSV Saturation component in [0, 1]. 

    :type: float
    '''

    v: float = None
    '''HSV Value component in [0, 1]. 

    :type: float
    '''

    def copy(self, ) -> 'Color':
        '''Returns a copy of this color. 

        :rtype: 'Color'
        :return:  A copy of the color. 
        '''
        pass

    def freeze(self, ):
        '''After this the object can be hashed, used in dictionaries & sets. 

        :return:  An instance of this object. 
        '''
        pass

    def __init__(self, val):
        '''

        '''
        pass


class Euler:
    '''This object gives access to Eulers in Blender. '''

    is_frozen: bool = None
    '''True when this object has been frozen (read-only). 

    :type: bool
    '''

    is_wrapped: bool = None
    '''True when this object wraps external data (read-only). 

    :type: bool
    '''

    order: str = None
    '''Euler rotation order. 

    :type: str
    '''

    owner = None
    '''The item this is wrapping or None (read-only). '''

    x: float = None
    '''Euler axis angle in radians. 

    :type: float
    '''

    y: float = None
    '''Euler axis angle in radians. 

    :type: float
    '''

    z: float = None
    '''Euler axis angle in radians. 

    :type: float
    '''

    def copy(self, ) -> 'Euler':
        '''Returns a copy of this euler. 

        :rtype: 'Euler'
        :return:  A copy of the euler. 
        '''
        pass

    def freeze(self, ):
        '''After this the object can be hashed, used in dictionaries & sets. 

        :return:  An instance of this object. 
        '''
        pass

    def make_compatible(self, other):
        '''Make this euler compatible with another, so interpolating between them works as intended. 

        '''
        pass

    def rotate(self, other: 'Euler'):
        '''Rotates the euler by another mathutils value. 

        :param other: rotation component of mathutils value 
        :type other: 'Euler'
        '''
        pass

    def rotate_axis(self, axis: str, angle: float):
        '''Rotates the euler a certain amount and returning a unique euler rotation (no 720 degree pitches). 

        :param axis: single character in [‘X, ‘Y’, ‘Z’]. 
        :type axis: str
        :param angle: angle in radians. 
        :type angle: float
        '''
        pass

    def to_matrix(self, ) -> 'Matrix':
        '''Return a matrix representation of the euler. 

        :rtype: 'Matrix'
        :return:  A 3x3 rotation matrix representation of the euler. 
        '''
        pass

    def to_quaternion(self, ) -> 'Quaternion':
        '''Return a quaternion representation of the euler. 

        :rtype: 'Quaternion'
        :return:  Quaternion representation of the euler. 
        '''
        pass

    def zero(self, ):
        '''Set all values to zero. 

        '''
        pass

    def __init__(self, val):
        '''

        '''
        pass


class Matrix:
    '''This object gives access to Matrices in Blender, supporting square and rectangular matrices from 2x2 up to 4x4. '''

    col: 'Matrix' = None
    '''Access the matrix by columns, 3x3 and 4x4 only, (read-only). 

    :type: 'Matrix'
    '''

    is_frozen: bool = None
    '''True when this object has been frozen (read-only). 

    :type: bool
    '''

    is_negative: bool = None
    '''True if this matrix results in a negative scale, 3x3 and 4x4 only, (read-only). 

    :type: bool
    '''

    is_orthogonal: bool = None
    '''True if this matrix is orthogonal, 3x3 and 4x4 only, (read-only). 

    :type: bool
    '''

    is_orthogonal_axis_vectors: bool = None
    '''True if this matrix has got orthogonal axis vectors, 3x3 and 4x4 only, (read-only). 

    :type: bool
    '''

    is_wrapped: bool = None
    '''True when this object wraps external data (read-only). 

    :type: bool
    '''

    median_scale: float = None
    '''The average scale applied to each axis (read-only). 

    :type: float
    '''

    owner = None
    '''The item this is wrapping or None (read-only). '''

    row: 'Matrix' = None
    '''Access the matrix by rows (default), (read-only). 

    :type: 'Matrix'
    '''

    translation: 'Vector' = None
    '''The translation component of the matrix. 

    :type: 'Vector'
    '''

    def adjugate(self, ):
        '''Set the matrix to its adjugate. 

        '''
        pass

    def adjugated(self, ) -> 'Matrix':
        '''Return an adjugated copy of the matrix. 

        :rtype: 'Matrix'
        :return:  the adjugated matrix. 
        '''
        pass

    def copy(self, ) -> 'Matrix':
        '''Returns a copy of this matrix. 

        :rtype: 'Matrix'
        :return:  an instance of itself 
        '''
        pass

    def decompose(self, ) -> 'Quaternion':
        '''Return the translation, rotation, and scale components of this matrix. 

        :rtype: 'Quaternion'
        :return:  tuple of translation, rotation, and scale 
        '''
        pass

    def determinant(self, ) -> float:
        '''Return the determinant of a matrix. 

        :rtype: float
        :return:  Return the determinant of a matrix. 
        '''
        pass

    def freeze(self, ):
        '''After this the object can be hashed, used in dictionaries & sets. 

        :return:  An instance of this object. 
        '''
        pass

    def identity(self, ):
        '''Set the matrix to the identity matrix. 

        '''
        pass

    def invert(self, fallback: 'Matrix' = None):
        '''Set the matrix to its inverse. 

        :param fallback: Set the matrix to this value when the inverse cannot be calculated (instead of raising a ValueError exception). 
        :type fallback: 'Matrix'
        '''
        pass

    def invert_safe(self, ):
        '''Set the matrix to its inverse, will never error. If degenerated (e.g. zero scale on an axis), add some epsilon to its diagonal, to get an invertible one. If tweaked matrix is still degenerated, set to the identity matrix instead. 

        '''
        pass

    def inverted(self, fallback=None) -> 'Matrix':
        '''Return an inverted copy of the matrix. 

        :param fallback: return this when the inverse can’t be calculated (instead of raising a ValueError). 
        :type fallback: 
        :rtype: 'Matrix'
        :return:  the inverted matrix or fallback when given. 
        '''
        pass

    def inverted_safe(self, ) -> 'Matrix':
        '''Return an inverted copy of the matrix, will never error. If degenerated (e.g. zero scale on an axis), add some epsilon to its diagonal, to get an invertible one. If tweaked matrix is still degenerated, return the identity matrix instead. 

        :rtype: 'Matrix'
        :return:  the inverted matrix. 
        '''
        pass

    def lerp(self, other: 'Matrix', factor: float) -> 'Matrix':
        '''Returns the interpolation of two matrices. Uses polar decomposition, see “Matrix Animation and Polar Decomposition”, Shoemake and Duff, 1992. 

        :param other: value to interpolate with. 
        :type other: 'Matrix'
        :param factor: The interpolation value in [0.0, 1.0]. 
        :type factor: float
        :rtype: 'Matrix'
        :return:  The interpolated matrix. 
        '''
        pass

    def normalize(self, ):
        '''Normalize each of the matrix columns. 

        '''
        pass

    def normalized(self, ) -> 'Matrix':
        '''Return a column normalized matrix 

        :rtype: 'Matrix'
        :return:  a column normalized matrix 
        '''
        pass

    def resize_4x4(self, ):
        '''Resize the matrix to 4x4. 

        '''
        pass

    def rotate(self, other: 'Euler'):
        '''Rotates the matrix by another mathutils value. 

        :param other: rotation component of mathutils value 
        :type other: 'Euler'
        '''
        pass

    def to_3x3(self, ) -> 'Matrix':
        '''Return a 3x3 copy of this matrix. 

        :rtype: 'Matrix'
        :return:  a new matrix. 
        '''
        pass

    def to_4x4(self, ) -> 'Matrix':
        '''Return a 4x4 copy of this matrix. 

        :rtype: 'Matrix'
        :return:  a new matrix. 
        '''
        pass

    def to_euler(self, order: str, euler_compat: 'Euler') -> 'Euler':
        '''Return an Euler representation of the rotation matrix (3x3 or 4x4 matrix only). 

        :param order: Optional rotation order argument in [‘XYZ’, ‘XZY’, ‘YXZ’, ‘YZX’, ‘ZXY’, ‘ZYX’]. 
        :type order: str
        :param euler_compat: Optional euler argument the new euler will be made compatible with (no axis flipping between them). Useful for converting a series of matrices to animation curves. 
        :type euler_compat: 'Euler'
        :rtype: 'Euler'
        :return:  Euler representation of the matrix. 
        '''
        pass

    def to_quaternion(self, ) -> 'Quaternion':
        '''Return a quaternion representation of the rotation matrix. 

        :rtype: 'Quaternion'
        :return:  Quaternion representation of the rotation matrix. 
        '''
        pass

    def to_scale(self, ) -> 'Vector':
        '''Return the scale part of a 3x3 or 4x4 matrix. 

        :rtype: 'Vector'
        :return:  Return the scale of a matrix. 
        '''
        pass

    def to_translation(self, ) -> 'Vector':
        '''Return the translation part of a 4 row matrix. 

        :rtype: 'Vector'
        :return:  Return the translation of a matrix. 
        '''
        pass

    def transpose(self, ):
        '''Set the matrix to its transpose. 

        '''
        pass

    def transposed(self, ) -> 'Matrix':
        '''Return a new, transposed matrix. 

        :rtype: 'Matrix'
        :return:  a transposed matrix 
        '''
        pass

    def zero(self, ) -> 'Matrix':
        '''Set all the matrix values to zero. 

        :rtype: 'Matrix'
        '''
        pass

    def __init__(self, val):
        '''

        '''
        pass


class Quaternion:
    '''The constructor takes arguments in various forms: '''

    angle: float = None
    '''Angle of the quaternion. 

    :type: float
    '''

    axis: 'Vector' = None
    '''Quaternion axis as a vector. 

    :type: 'Vector'
    '''

    is_frozen: bool = None
    '''True when this object has been frozen (read-only). 

    :type: bool
    '''

    is_wrapped: bool = None
    '''True when this object wraps external data (read-only). 

    :type: bool
    '''

    magnitude: float = None
    '''Size of the quaternion (read-only). 

    :type: float
    '''

    owner = None
    '''The item this is wrapping or None (read-only). '''

    w: float = None
    '''Quaternion axis value. 

    :type: float
    '''

    x: float = None
    '''Quaternion axis value. 

    :type: float
    '''

    y: float = None
    '''Quaternion axis value. 

    :type: float
    '''

    z: float = None
    '''Quaternion axis value. 

    :type: float
    '''

    def conjugate(self, ):
        '''Set the quaternion to its conjugate (negate x, y, z). 

        '''
        pass

    def conjugated(self, ) -> 'Quaternion':
        '''Return a new conjugated quaternion. 

        :rtype: 'Quaternion'
        :return:  a new quaternion. 
        '''
        pass

    def copy(self, ) -> 'Quaternion':
        '''Returns a copy of this quaternion. 

        :rtype: 'Quaternion'
        :return:  A copy of the quaternion. 
        '''
        pass

    def cross(self, other: 'Quaternion') -> 'Quaternion':
        '''Return the cross product of this quaternion and another. 

        :param other: The other quaternion to perform the cross product with. 
        :type other: 'Quaternion'
        :rtype: 'Quaternion'
        :return:  The cross product. 
        '''
        pass

    def dot(self, other: 'Quaternion') -> float:
        '''Return the dot product of this quaternion and another. 

        :param other: The other quaternion to perform the dot product with. 
        :type other: 'Quaternion'
        :rtype: float
        :return:  The dot product. 
        '''
        pass

    def freeze(self, ):
        '''After this the object can be hashed, used in dictionaries & sets. 

        :return:  An instance of this object. 
        '''
        pass

    def identity(self, ) -> 'Quaternion':
        '''Set the quaternion to an identity quaternion. 

        :rtype: 'Quaternion'
        '''
        pass

    def invert(self, ):
        '''Set the quaternion to its inverse. 

        '''
        pass

    def inverted(self, ) -> 'Quaternion':
        '''Return a new, inverted quaternion. 

        :rtype: 'Quaternion'
        :return:  the inverted value. 
        '''
        pass

    def negate(self, ) -> 'Quaternion':
        '''Set the quaternion to its negative. 

        :rtype: 'Quaternion'
        '''
        pass

    def normalize(self, ):
        '''Normalize the quaternion. 

        '''
        pass

    def normalized(self, ) -> 'Quaternion':
        '''Return a new normalized quaternion. 

        :rtype: 'Quaternion'
        :return:  a normalized copy. 
        '''
        pass

    def rotate(self, other: 'Euler'):
        '''Rotates the quaternion by another mathutils value. 

        :param other: rotation component of mathutils value 
        :type other: 'Euler'
        '''
        pass

    def rotation_difference(self, other: 'Quaternion') -> 'Quaternion':
        '''Returns a quaternion representing the rotational difference. 

        :param other: second quaternion. 
        :type other: 'Quaternion'
        :rtype: 'Quaternion'
        :return:  the rotational difference between the two quat rotations. 
        '''
        pass

    def slerp(self, other: 'Quaternion', factor: float) -> 'Quaternion':
        '''Returns the interpolation of two quaternions. 

        :param other: value to interpolate with. 
        :type other: 'Quaternion'
        :param factor: The interpolation value in [0.0, 1.0]. 
        :type factor: float
        :rtype: 'Quaternion'
        :return:  The interpolated rotation. 
        '''
        pass

    def to_axis_angle(self, ) -> float:
        '''Return the axis, angle representation of the quaternion. 

        :rtype: float
        :return:  axis, angle. 
        '''
        pass

    def to_euler(self, order: str, euler_compat: 'Euler') -> 'Euler':
        '''Return Euler representation of the quaternion. 

        :param order: Optional rotation order argument in [‘XYZ’, ‘XZY’, ‘YXZ’, ‘YZX’, ‘ZXY’, ‘ZYX’]. 
        :type order: str
        :param euler_compat: Optional euler argument the new euler will be made compatible with (no axis flipping between them). Useful for converting a series of matrices to animation curves. 
        :type euler_compat: 'Euler'
        :rtype: 'Euler'
        :return:  Euler representation of the quaternion. 
        '''
        pass

    def to_exponential_map(self, ) -> 'Vector':
        '''To convert back to a quaternion, pass it to the Quaternion constructor. 

        :rtype: 'Vector'
        :return:  exponential map. 
        '''
        pass

    def to_matrix(self, ) -> 'Matrix':
        '''Return a matrix representation of the quaternion. 

        :rtype: 'Matrix'
        :return:  A 3x3 rotation matrix representation of the quaternion. 
        '''
        pass

    def __init__(self, val):
        '''

        '''
        pass


class Vector:
    '''This object gives access to Vectors in Blender. '''

    is_frozen: bool = None
    '''True when this object has been frozen (read-only). 

    :type: bool
    '''

    is_wrapped: bool = None
    '''True when this object wraps external data (read-only). 

    :type: bool
    '''

    length: float = None
    '''Vector Length. 

    :type: float
    '''

    length_squared: float = None
    '''Vector length squared (v.dot(v)). 

    :type: float
    '''

    magnitude: float = None
    '''Vector Length. 

    :type: float
    '''

    owner = None
    '''The item this is wrapping or None (read-only). '''

    w: float = None
    '''Vector W axis (4D Vectors only). 

    :type: float
    '''

    ww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    www = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wwzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wxzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wywx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wywy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wywz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wyzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    wzzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    x: float = None
    '''Vector X axis. 

    :type: float
    '''

    xw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xwzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xxzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xywx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xywy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xywz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xyzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    xzzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    y: float = None
    '''Vector Y axis. 

    :type: float
    '''

    yw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    ywzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yxzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yywx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yywy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yywz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yyzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    yzzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    z: float = None
    '''Vector Z axis (3D Vectors only). 

    :type: float
    '''

    zw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zwzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zxzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zywx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zywy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zywz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zyzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzww = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzwx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzwy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzwz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzxw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzxx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzxy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzxz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzyw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzyx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzyy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzyz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzzw = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzzx = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzzy = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    zzzz = None
    '''Undocumented contribute <https://developer.blender.org/T51061> '''

    def angle(self, other: 'Vector', fallback=None) -> float:
        '''Return the angle between two vectors. 

        :param other: another vector to compare the angle with 
        :type other: 'Vector'
        :param fallback: return this when the angle can’t be calculated (zero length vector), (instead of raising a ValueError). 
        :type fallback: 
        :rtype: float
        :return:  angle in radians or fallback when given 
        '''
        pass

    def angle_signed(self, other: 'Vector', fallback) -> float:
        '''Return the signed angle between two 2D vectors (clockwise is positive). 

        :param other: another vector to compare the angle with 
        :type other: 'Vector'
        :param fallback: return this when the angle can’t be calculated (zero length vector), (instead of raising a ValueError). 
        :type fallback: 
        :rtype: float
        :return:  angle in radians or fallback when given 
        '''
        pass

    def copy(self, ) -> 'Vector':
        '''Returns a copy of this vector. 

        :rtype: 'Vector'
        :return:  A copy of the vector. 
        '''
        pass

    def cross(self, other: 'Vector') -> float:
        '''Return the cross product of this vector and another. 

        :param other: The other vector to perform the cross product with. 
        :type other: 'Vector'
        :rtype: float
        :return:  The cross product. 
        '''
        pass

    def dot(self, other: 'Vector') -> 'Vector':
        '''Return the dot product of this vector and another. 

        :param other: The other vector to perform the dot product with. 
        :type other: 'Vector'
        :rtype: 'Vector'
        :return:  The dot product. 
        '''
        pass

    def freeze(self, ):
        '''After this the object can be hashed, used in dictionaries & sets. 

        :return:  An instance of this object. 
        '''
        pass

    def lerp(self, other: 'Vector', factor: float) -> 'Vector':
        '''Returns the interpolation of two vectors. 

        :param other: value to interpolate with. 
        :type other: 'Vector'
        :param factor: The interpolation value in [0.0, 1.0]. 
        :type factor: float
        :rtype: 'Vector'
        :return:  The interpolated vector. 
        '''
        pass

    def negate(self, ):
        '''Set all values to their negative. 

        '''
        pass

    def normalize(self, ):
        '''Normalize the vector, making the length of the vector always 1.0. 

        '''
        pass

    def normalized(self, ) -> 'Vector':
        '''Return a new, normalized vector. 

        :rtype: 'Vector'
        :return:  a normalized copy of the vector 
        '''
        pass

    def orthogonal(self, ) -> 'Vector':
        '''Return a perpendicular vector. 

        :rtype: 'Vector'
        :return:  a new vector 90 degrees from this vector. 
        '''
        pass

    def project(self, other: 'Vector') -> 'Vector':
        '''Return the projection of this vector onto the other. 

        :param other: second vector. 
        :type other: 'Vector'
        :rtype: 'Vector'
        :return:  the parallel projection vector 
        '''
        pass

    def reflect(self, mirror: 'Vector') -> 'Vector':
        '''Return the reflection vector from the mirror argument. 

        :param mirror: This vector could be a normal from the reflecting surface. 
        :type mirror: 'Vector'
        :rtype: 'Vector'
        :return:  The reflected vector matching the size of this vector. 
        '''
        pass

    def resize(self, size=3):
        '''Resize the vector to have size number of elements. 

        '''
        pass

    def resize_2d(self, ):
        '''Resize the vector to 2D (x, y). 

        '''
        pass

    def resize_3d(self, ):
        '''Resize the vector to 3D (x, y, z). 

        '''
        pass

    def resize_4d(self, ):
        '''Resize the vector to 4D (x, y, z, w). 

        '''
        pass

    def resized(self, size=3) -> 'Vector':
        '''Return a resized copy of the vector with size number of elements. 

        :rtype: 'Vector'
        :return:  a new vector 
        '''
        pass

    def rotate(self, other: 'Euler'):
        '''Rotate the vector by a rotation value. 

        :param other: rotation component of mathutils value 
        :type other: 'Euler'
        '''
        pass

    def rotation_difference(self, other: 'Vector') -> 'Quaternion':
        '''Returns a quaternion representing the rotational difference between this vector and another. 

        :param other: second vector. 
        :type other: 'Vector'
        :rtype: 'Quaternion'
        :return:  the rotational difference between the two vectors. 
        '''
        pass

    def slerp(self, other: 'Vector', factor: float, fallback=None) -> 'Vector':
        '''Returns the interpolation of two non-zero vectors (spherical coordinates). 

        :param other: value to interpolate with. 
        :type other: 'Vector'
        :param factor: The interpolation value typically in [0.0, 1.0]. 
        :type factor: float
        :param fallback: return this when the vector can’t be calculated (zero length vector or direct opposites), (instead of raising a ValueError). 
        :type fallback: 
        :rtype: 'Vector'
        :return:  The interpolated vector. 
        '''
        pass

    def to_2d(self, ) -> 'Vector':
        '''Return a 2d copy of the vector. 

        :rtype: 'Vector'
        :return:  a new vector 
        '''
        pass

    def to_3d(self, ) -> 'Vector':
        '''Return a 3d copy of the vector. 

        :rtype: 'Vector'
        :return:  a new vector 
        '''
        pass

    def to_4d(self, ) -> 'Vector':
        '''Return a 4d copy of the vector. 

        :rtype: 'Vector'
        :return:  a new vector 
        '''
        pass

    def to_track_quat(self, track: str, up: str) -> 'Quaternion':
        '''Return a quaternion rotation from the vector and the track and up axis. 

        :param track: Track axis in [‘X’, ‘Y’, ‘Z’, ‘-X’, ‘-Y’, ‘-Z’]. 
        :type track: str
        :param up: Up axis in [‘X’, ‘Y’, ‘Z’]. 
        :type up: str
        :rtype: 'Quaternion'
        :return:  rotation from the vector and the track and up axis. 
        '''
        pass

    def to_tuple(self, precision: int = -1):
        '''Return this vector as a tuple with. 

        :param precision: The number to round the value to in [-1, 21]. 
        :type precision: int
        :return:  the values of the vector rounded by precision 
        '''
        pass

    def zero(self, ):
        '''Set all values to zero. 

        '''
        pass

    def __init__(self, val):
        '''

        '''
        pass



import sys
import typing
import bpy

from . import ops
from . import utils
from . import types
from . import geometry


def from_edit_mesh(mesh: 'bpy.types.Mesh') -> 'types.BMesh':
    '''Return a BMesh from this mesh, currently the mesh must already be in editmode. 

    :param mesh: The editmode mesh. 
    :type mesh: 'bpy.types.Mesh'
    :return:  the BMesh associated with this mesh. 
    '''

    pass


def new(use_operators: bool = True) -> 'types.BMesh':
    '''

    :param use_operators: Support calling operators in bmesh.ops (uses some extra memory per vert/edge/face). 
    :type use_operators: bool
    :return:  Return a new, empty BMesh. 
    '''

    pass


def update_edit_mesh(mesh: 'bpy.types.Mesh',
                     loop_triangles: bool = True,
                     destructive: bool = True):
    '''Update the mesh after changes to the BMesh in editmode, optionally recalculating n-gon tessellation. 

    :param mesh: The editmode mesh. 
    :type mesh: 'bpy.types.Mesh'
    :param loop_triangles: Option to recalculate n-gon tessellation. 
    :type loop_triangles: bool
    :param destructive: Use when geometry has been added or removed. 
    :type destructive: bool
    '''

    pass



import sys
import typing


def action_sanitize():
    '''Make action suitable for use as a Pose Library 

    '''

    pass


def apply_pose(pose_index: int = -1):
    '''Apply specified Pose Library pose to the rig 

    :param pose_index: Pose, Index of the pose to apply (-2 for no change to pose, -1 for poselib active pose) 
    :type pose_index: int
    '''

    pass


def browse_interactive(pose_index: int = -1):
    '''Interactively browse poses in 3D-View 

    :param pose_index: Pose, Index of the pose to apply (-2 for no change to pose, -1 for poselib active pose) 
    :type pose_index: int
    '''

    pass


def new():
    '''Add New Pose Library to active Object 

    '''

    pass


def pose_add(frame: int = 1, name: str = "Pose"):
    '''Add the current Pose to the active Pose Library 

    :param frame: Frame, Frame to store pose on 
    :type frame: int
    :param name: Pose Name, Name of newly added Pose 
    :type name: str
    '''

    pass


def pose_move(pose: typing.Union[int, str] = '',
              direction: typing.Union[int, str] = 'UP'):
    '''Move the pose up or down in the active Pose Library 

    :param pose: Pose, The pose to move 
    :type pose: typing.Union[int, str]
    :param direction: Direction, Direction to move the chosen pose towards 
    :type direction: typing.Union[int, str]
    '''

    pass


def pose_remove(pose: typing.Union[int, str] = ''):
    '''Remove nth pose from the active Pose Library 

    :param pose: Pose, The pose to remove 
    :type pose: typing.Union[int, str]
    '''

    pass


def pose_rename(name: str = "RenamedPose", pose: typing.Union[int, str] = ''):
    '''Rename specified pose from the active Pose Library 

    :param name: New Pose Name, New name for pose 
    :type name: str
    :param pose: Pose, The pose to rename 
    :type pose: typing.Union[int, str]
    '''

    pass


def unlink():
    '''Remove Pose Library from active Object 

    '''

    pass



import sys
import typing


def case_set(case: typing.Union[int, str] = 'LOWER'):
    '''Set font case 

    :param case: Case, Lower or upper case 
    :type case: typing.Union[int, str]
    '''

    pass


def case_toggle():
    '''Toggle font case 

    '''

    pass


def change_character(delta: int = 1):
    '''Change font character code 

    :param delta: Delta, Number to increase or decrease character code with 
    :type delta: int
    '''

    pass


def change_spacing(delta: int = 1):
    '''Change font spacing 

    :param delta: Delta, Amount to decrease or increase character spacing with 
    :type delta: int
    '''

    pass


def delete(type: typing.Union[int, str] = 'PREVIOUS_CHARACTER'):
    '''Delete text by cursor position 

    :param type: Type, Which part of the text to delete 
    :type type: typing.Union[int, str]
    '''

    pass


def line_break():
    '''Insert line break at cursor position 

    '''

    pass


def move(type: typing.Union[int, str] = 'LINE_BEGIN'):
    '''Move cursor to position type 

    :param type: Type, Where to move cursor to 
    :type type: typing.Union[int, str]
    '''

    pass


def move_select(type: typing.Union[int, str] = 'LINE_BEGIN'):
    '''Move the cursor while selecting 

    :param type: Type, Where to move cursor to, to make a selection 
    :type type: typing.Union[int, str]
    '''

    pass


def open(filepath: str = "",
         filter_blender: bool = False,
         filter_backup: bool = False,
         filter_image: bool = False,
         filter_movie: bool = False,
         filter_python: bool = False,
         filter_font: bool = True,
         filter_sound: bool = False,
         filter_text: bool = False,
         filter_btx: bool = False,
         filter_collada: bool = False,
         filter_alembic: bool = False,
         filter_folder: bool = True,
         filter_blenlib: bool = False,
         filemode: int = 9,
         relative_path: bool = True,
         display_type: typing.Union[int, str] = 'DEFAULT',
         sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
    '''Load a new font from a file 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param relative_path: Relative Path, Select the file relative to the blend file 
    :type relative_path: bool
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[int, str]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[int, str]
    '''

    pass


def select_all():
    '''Select all text 

    '''

    pass


def style_set(style: typing.Union[int, str] = 'BOLD', clear: bool = False):
    '''Set font style 

    :param style: Style, Style to set selection to 
    :type style: typing.Union[int, str]
    :param clear: Clear, Clear style rather than setting it 
    :type clear: bool
    '''

    pass


def style_toggle(style: typing.Union[int, str] = 'BOLD'):
    '''Toggle font style 

    :param style: Style, Style to set selection to 
    :type style: typing.Union[int, str]
    '''

    pass


def text_copy():
    '''Copy selected text to clipboard 

    '''

    pass


def text_cut():
    '''Cut selected text to clipboard 

    '''

    pass


def text_insert(text: str = "", accent: bool = False):
    '''Insert text at cursor position 

    :param text: Text, Text to insert at the cursor position 
    :type text: str
    :param accent: Accent mode, Next typed character will strike through previous, for special character input 
    :type accent: bool
    '''

    pass


def text_paste():
    '''Paste text from clipboard 

    '''

    pass


def text_paste_from_file(
        filepath: str = "",
        filter_blender: bool = False,
        filter_backup: bool = False,
        filter_image: bool = False,
        filter_movie: bool = False,
        filter_python: bool = False,
        filter_font: bool = False,
        filter_sound: bool = False,
        filter_text: bool = True,
        filter_btx: bool = False,
        filter_collada: bool = False,
        filter_alembic: bool = False,
        filter_folder: bool = True,
        filter_blenlib: bool = False,
        filemode: int = 9,
        display_type: typing.Union[int, str] = 'DEFAULT',
        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
    '''Paste contents from file 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[int, str]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[int, str]
    '''

    pass


def textbox_add():
    '''Add a new text box 

    '''

    pass


def textbox_remove(index: int = 0):
    '''Remove the textbox 

    :param index: Index, The current text box 
    :type index: int
    '''

    pass


def unlink():
    '''Unlink active font data-block 

    '''

    pass



import sys
import typing


def bend(value: float = (0.0),
         mirror: bool = False,
         use_proportional_edit: bool = False,
         proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
         proportional_size: float = 1.0,
         use_proportional_connected: bool = False,
         use_proportional_projected: bool = False,
         snap: bool = False,
         snap_target: typing.Union[int, str] = 'CLOSEST',
         snap_point: float = (0.0, 0.0, 0.0),
         snap_align: bool = False,
         snap_normal: float = (0.0, 0.0, 0.0),
         gpencil_strokes: bool = False,
         center_override: float = (0.0, 0.0, 0.0),
         release_confirm: bool = False,
         use_accurate: bool = False):
    '''Bend selected items between the 3D cursor and the mouse 

    :param value: Angle 
    :type value: float
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes 
    :type gpencil_strokes: bool
    :param center_override: Center Override, Force using this center value (when set) 
    :type center_override: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def create_orientation(name: str = "",
                       use_view: bool = False,
                       use: bool = False,
                       overwrite: bool = False):
    '''Create transformation orientation from selection 

    :param name: Name, Name of the new custom orientation 
    :type name: str
    :param use_view: Use View, Use the current view instead of the active object to create the new orientation 
    :type use_view: bool
    :param use: Use after creation, Select orientation after its creation 
    :type use: bool
    :param overwrite: Overwrite previous, Overwrite previously created orientation with same name 
    :type overwrite: bool
    '''

    pass


def delete_orientation():
    '''Delete transformation orientation 

    '''

    pass


def edge_bevelweight(value: float = 0.0,
                     snap: bool = False,
                     snap_target: typing.Union[int, str] = 'CLOSEST',
                     snap_point: float = (0.0, 0.0, 0.0),
                     snap_align: bool = False,
                     snap_normal: float = (0.0, 0.0, 0.0),
                     release_confirm: bool = False,
                     use_accurate: bool = False):
    '''Change the bevel weight of edges 

    :param value: Factor 
    :type value: float
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def edge_crease(value: float = 0.0,
                snap: bool = False,
                snap_target: typing.Union[int, str] = 'CLOSEST',
                snap_point: float = (0.0, 0.0, 0.0),
                snap_align: bool = False,
                snap_normal: float = (0.0, 0.0, 0.0),
                release_confirm: bool = False,
                use_accurate: bool = False):
    '''Change the crease of edges 

    :param value: Factor 
    :type value: float
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def edge_slide(value: float = 0.0,
               single_side: bool = False,
               use_even: bool = False,
               flipped: bool = False,
               use_clamp: bool = True,
               mirror: bool = False,
               snap: bool = False,
               snap_target: typing.Union[int, str] = 'CLOSEST',
               snap_point: float = (0.0, 0.0, 0.0),
               snap_align: bool = False,
               snap_normal: float = (0.0, 0.0, 0.0),
               correct_uv: bool = True,
               release_confirm: bool = False,
               use_accurate: bool = False):
    '''Slide an edge loop along a mesh 

    :param value: Factor 
    :type value: float
    :param single_side: Single Side 
    :type single_side: bool
    :param use_even: Even, Make the edge loop match the shape of the adjacent edge loop 
    :type use_even: bool
    :param flipped: Flipped, When Even mode is active, flips between the two adjacent edge loops 
    :type flipped: bool
    :param use_clamp: Clamp, Clamp within the edge extents 
    :type use_clamp: bool
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param correct_uv: Correct UVs, Correct UV coordinates when transforming 
    :type correct_uv: bool
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def from_gizmo():
    '''Transform selected items by mode type 

    '''

    pass


def mirror(orient_type: typing.Union[int, str] = 'GLOBAL',
           orient_matrix: float = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0,
                                                                      0.0)),
           orient_matrix_type: typing.Union[int, str] = 'GLOBAL',
           constraint_axis: bool = (False, False, False),
           use_proportional_edit: bool = False,
           proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
           proportional_size: float = 1.0,
           use_proportional_connected: bool = False,
           use_proportional_projected: bool = False,
           gpencil_strokes: bool = False,
           center_override: float = (0.0, 0.0, 0.0),
           release_confirm: bool = False,
           use_accurate: bool = False):
    '''Mirror selected items around one or more axes 

    :param orient_type: Orientation, Transformation orientation 
    :type orient_type: typing.Union[int, str]
    :param orient_matrix: Matrix 
    :type orient_matrix: float
    :param orient_matrix_type: Matrix Orientation 
    :type orient_matrix_type: typing.Union[int, str]
    :param constraint_axis: Constraint Axis 
    :type constraint_axis: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes 
    :type gpencil_strokes: bool
    :param center_override: Center Override, Force using this center value (when set) 
    :type center_override: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def push_pull(value: float = 0.0,
              mirror: bool = False,
              use_proportional_edit: bool = False,
              proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
              proportional_size: float = 1.0,
              use_proportional_connected: bool = False,
              use_proportional_projected: bool = False,
              snap: bool = False,
              snap_target: typing.Union[int, str] = 'CLOSEST',
              snap_point: float = (0.0, 0.0, 0.0),
              snap_align: bool = False,
              snap_normal: float = (0.0, 0.0, 0.0),
              center_override: float = (0.0, 0.0, 0.0),
              release_confirm: bool = False,
              use_accurate: bool = False):
    '''Push/Pull selected items 

    :param value: Distance 
    :type value: float
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param center_override: Center Override, Force using this center value (when set) 
    :type center_override: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def resize(value: float = (1.0, 1.0, 1.0),
           orient_type: typing.Union[int, str] = 'GLOBAL',
           orient_matrix: float = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0,
                                                                      0.0)),
           orient_matrix_type: typing.Union[int, str] = 'GLOBAL',
           constraint_axis: bool = (False, False, False),
           mirror: bool = False,
           use_proportional_edit: bool = False,
           proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
           proportional_size: float = 1.0,
           use_proportional_connected: bool = False,
           use_proportional_projected: bool = False,
           snap: bool = False,
           snap_target: typing.Union[int, str] = 'CLOSEST',
           snap_point: float = (0.0, 0.0, 0.0),
           snap_align: bool = False,
           snap_normal: float = (0.0, 0.0, 0.0),
           gpencil_strokes: bool = False,
           texture_space: bool = False,
           remove_on_cancel: bool = False,
           center_override: float = (0.0, 0.0, 0.0),
           release_confirm: bool = False,
           use_accurate: bool = False):
    '''Scale (resize) selected items 

    :param value: Scale 
    :type value: float
    :param orient_type: Orientation, Transformation orientation 
    :type orient_type: typing.Union[int, str]
    :param orient_matrix: Matrix 
    :type orient_matrix: float
    :param orient_matrix_type: Matrix Orientation 
    :type orient_matrix_type: typing.Union[int, str]
    :param constraint_axis: Constraint Axis 
    :type constraint_axis: bool
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes 
    :type gpencil_strokes: bool
    :param texture_space: Edit Texture Space, Edit Object data texture space 
    :type texture_space: bool
    :param remove_on_cancel: Remove on Cancel, Remove elements on cancel 
    :type remove_on_cancel: bool
    :param center_override: Center Override, Force using this center value (when set) 
    :type center_override: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def rotate(value: float = 0.0,
           orient_axis: typing.Union[int, str] = 'Z',
           orient_type: typing.Union[int, str] = 'GLOBAL',
           orient_matrix: float = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0,
                                                                      0.0)),
           orient_matrix_type: typing.Union[int, str] = 'GLOBAL',
           constraint_axis: bool = (False, False, False),
           mirror: bool = False,
           use_proportional_edit: bool = False,
           proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
           proportional_size: float = 1.0,
           use_proportional_connected: bool = False,
           use_proportional_projected: bool = False,
           snap: bool = False,
           snap_target: typing.Union[int, str] = 'CLOSEST',
           snap_point: float = (0.0, 0.0, 0.0),
           snap_align: bool = False,
           snap_normal: float = (0.0, 0.0, 0.0),
           gpencil_strokes: bool = False,
           center_override: float = (0.0, 0.0, 0.0),
           release_confirm: bool = False,
           use_accurate: bool = False):
    '''Rotate selected items 

    :param value: Angle 
    :type value: float
    :param orient_axis: Axis 
    :type orient_axis: typing.Union[int, str]
    :param orient_type: Orientation, Transformation orientation 
    :type orient_type: typing.Union[int, str]
    :param orient_matrix: Matrix 
    :type orient_matrix: float
    :param orient_matrix_type: Matrix Orientation 
    :type orient_matrix_type: typing.Union[int, str]
    :param constraint_axis: Constraint Axis 
    :type constraint_axis: bool
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes 
    :type gpencil_strokes: bool
    :param center_override: Center Override, Force using this center value (when set) 
    :type center_override: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def rotate_normal(value: float = 0.0,
                  orient_axis: typing.Union[int, str] = 'Z',
                  orient_type: typing.Union[int, str] = 'GLOBAL',
                  orient_matrix: float = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0),
                                          (0.0, 0.0, 0.0)),
                  orient_matrix_type: typing.Union[int, str] = 'GLOBAL',
                  constraint_axis: bool = (False, False, False),
                  mirror: bool = False,
                  release_confirm: bool = False,
                  use_accurate: bool = False):
    '''Rotate split normal of selected items 

    :param value: Angle 
    :type value: float
    :param orient_axis: Axis 
    :type orient_axis: typing.Union[int, str]
    :param orient_type: Orientation, Transformation orientation 
    :type orient_type: typing.Union[int, str]
    :param orient_matrix: Matrix 
    :type orient_matrix: float
    :param orient_matrix_type: Matrix Orientation 
    :type orient_matrix_type: typing.Union[int, str]
    :param constraint_axis: Constraint Axis 
    :type constraint_axis: bool
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def select_orientation(orientation: typing.Union[int, str] = 'GLOBAL'):
    '''Select transformation orientation 

    :param orientation: Orientation, Transformation orientation 
    :type orientation: typing.Union[int, str]
    '''

    pass


def seq_slide(value: float = (0.0, 0.0),
              snap: bool = False,
              snap_target: typing.Union[int, str] = 'CLOSEST',
              snap_point: float = (0.0, 0.0, 0.0),
              snap_align: bool = False,
              snap_normal: float = (0.0, 0.0, 0.0),
              release_confirm: bool = False,
              use_accurate: bool = False):
    '''Slide a sequence strip in time 

    :param value: Offset 
    :type value: float
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def shear(value: float = 0.0,
          shear_axis: typing.Union[int, str] = 'X',
          orient_axis: typing.Union[int, str] = 'Z',
          orient_axis_ortho: typing.Union[int, str] = 'Y',
          orient_type: typing.Union[int, str] = 'GLOBAL',
          orient_matrix: float = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0,
                                                                     0.0)),
          orient_matrix_type: typing.Union[int, str] = 'GLOBAL',
          mirror: bool = False,
          use_proportional_edit: bool = False,
          proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
          proportional_size: float = 1.0,
          use_proportional_connected: bool = False,
          use_proportional_projected: bool = False,
          snap: bool = False,
          snap_target: typing.Union[int, str] = 'CLOSEST',
          snap_point: float = (0.0, 0.0, 0.0),
          snap_align: bool = False,
          snap_normal: float = (0.0, 0.0, 0.0),
          gpencil_strokes: bool = False,
          release_confirm: bool = False,
          use_accurate: bool = False):
    '''Shear selected items along the horizontal screen axis 

    :param value: Offset 
    :type value: float
    :param shear_axis: Shear Axis 
    :type shear_axis: typing.Union[int, str]
    :param orient_axis: Axis 
    :type orient_axis: typing.Union[int, str]
    :param orient_axis_ortho: Axis Ortho 
    :type orient_axis_ortho: typing.Union[int, str]
    :param orient_type: Orientation, Transformation orientation 
    :type orient_type: typing.Union[int, str]
    :param orient_matrix: Matrix 
    :type orient_matrix: float
    :param orient_matrix_type: Matrix Orientation 
    :type orient_matrix_type: typing.Union[int, str]
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes 
    :type gpencil_strokes: bool
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def shrink_fatten(value: float = 0.0,
                  use_even_offset: bool = False,
                  mirror: bool = False,
                  use_proportional_edit: bool = False,
                  proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
                  proportional_size: float = 1.0,
                  use_proportional_connected: bool = False,
                  use_proportional_projected: bool = False,
                  snap: bool = False,
                  snap_target: typing.Union[int, str] = 'CLOSEST',
                  snap_point: float = (0.0, 0.0, 0.0),
                  snap_align: bool = False,
                  snap_normal: float = (0.0, 0.0, 0.0),
                  release_confirm: bool = False,
                  use_accurate: bool = False):
    '''Shrink/fatten selected vertices along normals 

    :param value: Offset 
    :type value: float
    :param use_even_offset: Offset Even, Scale the offset to give more even thickness 
    :type use_even_offset: bool
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def skin_resize(value: float = (1.0, 1.0, 1.0),
                orient_type: typing.Union[int, str] = 'GLOBAL',
                orient_matrix: float = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0),
                                        (0.0, 0.0, 0.0)),
                orient_matrix_type: typing.Union[int, str] = 'GLOBAL',
                constraint_axis: bool = (False, False, False),
                mirror: bool = False,
                use_proportional_edit: bool = False,
                proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
                proportional_size: float = 1.0,
                use_proportional_connected: bool = False,
                use_proportional_projected: bool = False,
                snap: bool = False,
                snap_target: typing.Union[int, str] = 'CLOSEST',
                snap_point: float = (0.0, 0.0, 0.0),
                snap_align: bool = False,
                snap_normal: float = (0.0, 0.0, 0.0),
                release_confirm: bool = False,
                use_accurate: bool = False):
    '''Scale selected vertices’ skin radii 

    :param value: Scale 
    :type value: float
    :param orient_type: Orientation, Transformation orientation 
    :type orient_type: typing.Union[int, str]
    :param orient_matrix: Matrix 
    :type orient_matrix: float
    :param orient_matrix_type: Matrix Orientation 
    :type orient_matrix_type: typing.Union[int, str]
    :param constraint_axis: Constraint Axis 
    :type constraint_axis: bool
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def tilt(value: float = 0.0,
         mirror: bool = False,
         use_proportional_edit: bool = False,
         proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
         proportional_size: float = 1.0,
         use_proportional_connected: bool = False,
         use_proportional_projected: bool = False,
         snap: bool = False,
         snap_target: typing.Union[int, str] = 'CLOSEST',
         snap_point: float = (0.0, 0.0, 0.0),
         snap_align: bool = False,
         snap_normal: float = (0.0, 0.0, 0.0),
         release_confirm: bool = False,
         use_accurate: bool = False):
    '''Tilt selected control vertices of 3D curve 

    :param value: Angle 
    :type value: float
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def tosphere(value: float = 0.0,
             mirror: bool = False,
             use_proportional_edit: bool = False,
             proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
             proportional_size: float = 1.0,
             use_proportional_connected: bool = False,
             use_proportional_projected: bool = False,
             snap: bool = False,
             snap_target: typing.Union[int, str] = 'CLOSEST',
             snap_point: float = (0.0, 0.0, 0.0),
             snap_align: bool = False,
             snap_normal: float = (0.0, 0.0, 0.0),
             gpencil_strokes: bool = False,
             center_override: float = (0.0, 0.0, 0.0),
             release_confirm: bool = False,
             use_accurate: bool = False):
    '''Move selected vertices outward in a spherical shape around mesh center 

    :param value: Factor 
    :type value: float
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes 
    :type gpencil_strokes: bool
    :param center_override: Center Override, Force using this center value (when set) 
    :type center_override: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def trackball(value: float = (0.0, 0.0),
              mirror: bool = False,
              use_proportional_edit: bool = False,
              proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
              proportional_size: float = 1.0,
              use_proportional_connected: bool = False,
              use_proportional_projected: bool = False,
              snap: bool = False,
              snap_target: typing.Union[int, str] = 'CLOSEST',
              snap_point: float = (0.0, 0.0, 0.0),
              snap_align: bool = False,
              snap_normal: float = (0.0, 0.0, 0.0),
              gpencil_strokes: bool = False,
              center_override: float = (0.0, 0.0, 0.0),
              release_confirm: bool = False,
              use_accurate: bool = False):
    '''Trackball style rotation of selected items 

    :param value: Angle 
    :type value: float
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes 
    :type gpencil_strokes: bool
    :param center_override: Center Override, Force using this center value (when set) 
    :type center_override: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def transform(mode: typing.Union[int, str] = 'TRANSLATION',
              value: float = (0.0, 0.0, 0.0, 0.0),
              orient_axis: typing.Union[int, str] = 'Z',
              orient_type: typing.Union[int, str] = 'GLOBAL',
              orient_matrix: float = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0),
                                      (0.0, 0.0, 0.0)),
              orient_matrix_type: typing.Union[int, str] = 'GLOBAL',
              constraint_axis: bool = (False, False, False),
              mirror: bool = False,
              use_proportional_edit: bool = False,
              proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
              proportional_size: float = 1.0,
              use_proportional_connected: bool = False,
              use_proportional_projected: bool = False,
              snap: bool = False,
              snap_target: typing.Union[int, str] = 'CLOSEST',
              snap_point: float = (0.0, 0.0, 0.0),
              snap_align: bool = False,
              snap_normal: float = (0.0, 0.0, 0.0),
              gpencil_strokes: bool = False,
              center_override: float = (0.0, 0.0, 0.0),
              release_confirm: bool = False,
              use_accurate: bool = False):
    '''Transform selected items by mode type 

    :param mode: Mode 
    :type mode: typing.Union[int, str]
    :param value: Values 
    :type value: float
    :param orient_axis: Axis 
    :type orient_axis: typing.Union[int, str]
    :param orient_type: Orientation, Transformation orientationGLOBAL Global, Align the transformation axes to world space.LOCAL Local, Align the transformation axes to the selected objects’ local space.NORMAL Normal, Align the transformation axes to average normal of selected elements (bone Y axis for pose mode).GIMBAL Gimbal, Align each axis to the Euler rotation axis as used for input.VIEW View, Align the transformation axes to the window.CURSOR Cursor, Align the transformation axes to the 3D cursor. 
    :type orient_type: typing.Union[int, str]
    :param orient_matrix: Matrix 
    :type orient_matrix: float
    :param orient_matrix_type: Matrix OrientationGLOBAL Global, Align the transformation axes to world space.LOCAL Local, Align the transformation axes to the selected objects’ local space.NORMAL Normal, Align the transformation axes to average normal of selected elements (bone Y axis for pose mode).GIMBAL Gimbal, Align each axis to the Euler rotation axis as used for input.VIEW View, Align the transformation axes to the window.CURSOR Cursor, Align the transformation axes to the 3D cursor. 
    :type orient_matrix_type: typing.Union[int, str]
    :param constraint_axis: Constraint Axis 
    :type constraint_axis: bool
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes 
    :type gpencil_strokes: bool
    :param center_override: Center Override, Force using this center value (when set) 
    :type center_override: float
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def translate(value: float = (0.0, 0.0, 0.0),
              orient_type: typing.Union[int, str] = 'GLOBAL',
              orient_matrix: float = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0),
                                      (0.0, 0.0, 0.0)),
              orient_matrix_type: typing.Union[int, str] = 'GLOBAL',
              constraint_axis: bool = (False, False, False),
              mirror: bool = False,
              use_proportional_edit: bool = False,
              proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
              proportional_size: float = 1.0,
              use_proportional_connected: bool = False,
              use_proportional_projected: bool = False,
              snap: bool = False,
              snap_target: typing.Union[int, str] = 'CLOSEST',
              snap_point: float = (0.0, 0.0, 0.0),
              snap_align: bool = False,
              snap_normal: float = (0.0, 0.0, 0.0),
              gpencil_strokes: bool = False,
              cursor_transform: bool = False,
              texture_space: bool = False,
              remove_on_cancel: bool = False,
              release_confirm: bool = False,
              use_accurate: bool = False):
    '''Move selected items 

    :param value: Move 
    :type value: float
    :param orient_type: Orientation, Transformation orientationGLOBAL Global, Align the transformation axes to world space.LOCAL Local, Align the transformation axes to the selected objects’ local space.NORMAL Normal, Align the transformation axes to average normal of selected elements (bone Y axis for pose mode).GIMBAL Gimbal, Align each axis to the Euler rotation axis as used for input.VIEW View, Align the transformation axes to the window.CURSOR Cursor, Align the transformation axes to the 3D cursor. 
    :type orient_type: typing.Union[int, str]
    :param orient_matrix: Matrix 
    :type orient_matrix: float
    :param orient_matrix_type: Matrix OrientationGLOBAL Global, Align the transformation axes to world space.LOCAL Local, Align the transformation axes to the selected objects’ local space.NORMAL Normal, Align the transformation axes to average normal of selected elements (bone Y axis for pose mode).GIMBAL Gimbal, Align each axis to the Euler rotation axis as used for input.VIEW View, Align the transformation axes to the window.CURSOR Cursor, Align the transformation axes to the 3D cursor. 
    :type orient_matrix_type: typing.Union[int, str]
    :param constraint_axis: Constraint Axis 
    :type constraint_axis: bool
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param use_proportional_edit: Proportional Editing 
    :type use_proportional_edit: bool
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing modeSMOOTH Smooth, Smooth falloff.SPHERE Sphere, Spherical falloff.ROOT Root, Root falloff.INVERSE_SQUARE Inverse Square, Inverse Square falloff.SHARP Sharp, Sharp falloff.LINEAR Linear, Linear falloff.CONSTANT Constant, Constant falloff.RANDOM Random, Random falloff. 
    :type proportional_edit_falloff: typing.Union[int, str]
    :param proportional_size: Proportional Size 
    :type proportional_size: float
    :param use_proportional_connected: Connected 
    :type use_proportional_connected: bool
    :param use_proportional_projected: Projected (2D) 
    :type use_proportional_projected: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes 
    :type gpencil_strokes: bool
    :param cursor_transform: Transform Cursor 
    :type cursor_transform: bool
    :param texture_space: Edit Texture Space, Edit Object data texture space 
    :type texture_space: bool
    :param remove_on_cancel: Remove on Cancel, Remove elements on cancel 
    :type remove_on_cancel: bool
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def vert_slide(value: float = 0.0,
               use_even: bool = False,
               flipped: bool = False,
               use_clamp: bool = True,
               mirror: bool = False,
               snap: bool = False,
               snap_target: typing.Union[int, str] = 'CLOSEST',
               snap_point: float = (0.0, 0.0, 0.0),
               snap_align: bool = False,
               snap_normal: float = (0.0, 0.0, 0.0),
               correct_uv: bool = True,
               release_confirm: bool = False,
               use_accurate: bool = False):
    '''Slide a vertex along a mesh 

    :param value: Factor 
    :type value: float
    :param use_even: Even, Make the edge loop match the shape of the adjacent edge loop 
    :type use_even: bool
    :param flipped: Flipped, When Even mode is active, flips between the two adjacent edge loops 
    :type flipped: bool
    :param use_clamp: Clamp, Clamp within the edge extents 
    :type use_clamp: bool
    :param mirror: Mirror Editing 
    :type mirror: bool
    :param snap: Use Snapping Options 
    :type snap: bool
    :param snap_target: TargetCLOSEST Closest, Snap closest point onto target.CENTER Center, Snap transformation center onto target.MEDIAN Median, Snap median onto target.ACTIVE Active, Snap active onto target. 
    :type snap_target: typing.Union[int, str]
    :param snap_point: Point 
    :type snap_point: float
    :param snap_align: Align with Point Normal 
    :type snap_align: bool
    :param snap_normal: Normal 
    :type snap_normal: float
    :param correct_uv: Correct UVs, Correct UV coordinates when transforming 
    :type correct_uv: bool
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button 
    :type release_confirm: bool
    :param use_accurate: Accurate, Use accurate transformation 
    :type use_accurate: bool
    '''

    pass


def vertex_random(offset: float = 0.1,
                  uniform: float = 0.0,
                  normal: float = 0.0,
                  seed: int = 0):
    '''Randomize vertices 

    :param offset: Amount, Distance to offset 
    :type offset: float
    :param uniform: Uniform, Increase for uniform offset distance 
    :type uniform: float
    :param normal: Normal, Align offset direction to normals 
    :type normal: float
    :param seed: Random Seed, Seed for the random number generator 
    :type seed: int
    '''

    pass


def vertex_warp(warp_angle: float = 6.28319,
                offset_angle: float = 0.0,
                min: float = -1,
                max: float = 1.0,
                viewmat: float = ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0),
                                  (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)),
                center: float = (0.0, 0.0, 0.0)):
    '''Warp vertices around the cursor 

    :param warp_angle: Warp Angle, Amount to warp about the cursor 
    :type warp_angle: float
    :param offset_angle: Offset Angle, Angle to use as the basis for warping 
    :type offset_angle: float
    :param min: Min 
    :type min: float
    :param max: Max 
    :type max: float
    :param viewmat: Matrix 
    :type viewmat: float
    :param center: Center 
    :type center: float
    '''

    pass



import sys
import typing


def autocomplete():
    '''Evaluate the namespace up until the cursor and give a list of options or complete the name if there is only one 

    '''

    pass


def banner():
    '''Print a message when the terminal initializes 

    '''

    pass


def clear(scrollback: bool = True, history: bool = False):
    '''Clear text by type 

    :param scrollback: Scrollback, Clear the scrollback history 
    :type scrollback: bool
    :param history: History, Clear the command history 
    :type history: bool
    '''

    pass


def clear_line():
    '''Clear the line and store in history 

    '''

    pass


def copy():
    '''Copy selected text to clipboard 

    '''

    pass


def copy_as_script():
    '''Copy the console contents for use in a script 

    '''

    pass


def delete(type: typing.Union[int, str] = 'NEXT_CHARACTER'):
    '''Delete text by cursor position 

    :param type: Type, Which part of the text to delete 
    :type type: typing.Union[int, str]
    '''

    pass


def execute(interactive: bool = False):
    '''Execute the current console line as a python expression 

    :param interactive: interactive 
    :type interactive: bool
    '''

    pass


def history_append(text: str = "",
                   current_character: int = 0,
                   remove_duplicates: bool = False):
    '''Append history at cursor position 

    :param text: Text, Text to insert at the cursor position 
    :type text: str
    :param current_character: Cursor, The index of the cursor 
    :type current_character: int
    :param remove_duplicates: Remove Duplicates, Remove duplicate items in the history 
    :type remove_duplicates: bool
    '''

    pass


def history_cycle(reverse: bool = False):
    '''Cycle through history 

    :param reverse: Reverse, Reverse cycle history 
    :type reverse: bool
    '''

    pass


def indent():
    '''Add 4 spaces at line beginning 

    '''

    pass


def insert(text: str = ""):
    '''Insert text at cursor position 

    :param text: Text, Text to insert at the cursor position 
    :type text: str
    '''

    pass


def language(language: str = ""):
    '''Set the current language for this console 

    :param language: Language 
    :type language: str
    '''

    pass


def move(type: typing.Union[int, str] = 'LINE_BEGIN'):
    '''Move cursor position 

    :param type: Type, Where to move cursor to 
    :type type: typing.Union[int, str]
    '''

    pass


def paste():
    '''Paste text from clipboard 

    '''

    pass


def scrollback_append(text: str = "", type: typing.Union[int, str] = 'OUTPUT'):
    '''Append scrollback text by type 

    :param text: Text, Text to insert at the cursor position 
    :type text: str
    :param type: Type, Console output type 
    :type type: typing.Union[int, str]
    '''

    pass


def select_set():
    '''Set the console selection 

    '''

    pass


def select_word():
    '''Select word at cursor position 

    '''

    pass


def unindent():
    '''Delete 4 spaces from line beginning 

    '''

    pass



import sys
import typing
import bpy


def align(axis: typing.Union[int, str] = 'ALIGN_AUTO'):
    '''Align selected UV vertices to an axis 

    :param axis: Axis, Axis to align UV locations onALIGN_S Straighten, Align UVs along the line defined by the endpoints.ALIGN_T Straighten X, Align UVs along the line defined by the endpoints along the X axis.ALIGN_U Straighten Y, Align UVs along the line defined by the endpoints along the Y axis.ALIGN_AUTO Align Auto, Automatically choose the axis on which there is most alignment already.ALIGN_X Align X, Align UVs on X axis.ALIGN_Y Align Y, Align UVs on Y axis. 
    :type axis: typing.Union[int, str]
    '''

    pass


def average_islands_scale():
    '''Average the size of separate UV islands, based on their area in 3D space 

    '''

    pass


def cube_project(cube_size: float = 1.0,
                 correct_aspect: bool = True,
                 clip_to_bounds: bool = False,
                 scale_to_bounds: bool = False):
    '''Project the UV vertices of the mesh over the six faces of a cube 

    :param cube_size: Cube Size, Size of the cube to project on 
    :type cube_size: float
    :param correct_aspect: Correct Aspect, Map UVs taking image aspect ratio into account 
    :type correct_aspect: bool
    :param clip_to_bounds: Clip to Bounds, Clip UV coordinates to bounds after unwrapping 
    :type clip_to_bounds: bool
    :param scale_to_bounds: Scale to Bounds, Scale UV coordinates to bounds after unwrapping 
    :type scale_to_bounds: bool
    '''

    pass


def cursor_set(location: float = (0.0, 0.0)):
    '''Set 2D cursor location 

    :param location: Location, Cursor location in normalized (0.0-1.0) coordinates 
    :type location: float
    '''

    pass


def cylinder_project(direction: typing.Union[int, str] = 'VIEW_ON_EQUATOR',
                     align: typing.Union[int, str] = 'POLAR_ZX',
                     radius: float = 1.0,
                     correct_aspect: bool = True,
                     clip_to_bounds: bool = False,
                     scale_to_bounds: bool = False):
    '''Project the UV vertices of the mesh over the curved wall of a cylinder 

    :param direction: Direction, Direction of the sphere or cylinderVIEW_ON_EQUATOR View on Equator, 3D view is on the equator.VIEW_ON_POLES View on Poles, 3D view is on the poles.ALIGN_TO_OBJECT Align to Object, Align according to object transform. 
    :type direction: typing.Union[int, str]
    :param align: Align, How to determine rotation around the polePOLAR_ZX Polar ZX, Polar 0 is X.POLAR_ZY Polar ZY, Polar 0 is Y. 
    :type align: typing.Union[int, str]
    :param radius: Radius, Radius of the sphere or cylinder 
    :type radius: float
    :param correct_aspect: Correct Aspect, Map UVs taking image aspect ratio into account 
    :type correct_aspect: bool
    :param clip_to_bounds: Clip to Bounds, Clip UV coordinates to bounds after unwrapping 
    :type clip_to_bounds: bool
    :param scale_to_bounds: Scale to Bounds, Scale UV coordinates to bounds after unwrapping 
    :type scale_to_bounds: bool
    '''

    pass


def export_layout(filepath: str = "",
                  export_all: bool = False,
                  modified: bool = False,
                  mode: typing.Union[int, str] = 'PNG',
                  size: int = (1024, 1024),
                  opacity: float = 0.25):
    '''Export UV layout to file 

    :param filepath: filepath 
    :type filepath: str
    :param export_all: All UVs, Export all UVs in this mesh (not just visible ones) 
    :type export_all: bool
    :param modified: Modified, Exports UVs from the modified mesh 
    :type modified: bool
    :param mode: Format, File format to export the UV layout toSVG Scalable Vector Graphic (.svg), Export the UV layout to a vector SVG file.EPS Encapsulate PostScript (.eps), Export the UV layout to a vector EPS file.PNG PNG Image (.png), Export the UV layout to a bitmap image. 
    :type mode: typing.Union[int, str]
    :param size: size, Dimensions of the exported file 
    :type size: int
    :param opacity: Fill Opacity, Set amount of opacity for exported UV layout 
    :type opacity: float
    '''

    pass


def follow_active_quads(mode: typing.Union[int, str] = 'LENGTH_AVERAGE'):
    '''Follow UVs from active quads along continuous face loops 

    :param mode: Edge Length Mode, Method to space UV edge loopsEVEN Even, Space all UVs evenly.LENGTH Length, Average space UVs edge length of each loop.LENGTH_AVERAGE Length Average, Average space UVs edge length of each loop. 
    :type mode: typing.Union[int, str]
    '''

    pass


def hide(unselected: bool = False):
    '''Hide (un)selected UV vertices 

    :param unselected: Unselected, Hide unselected rather than selected 
    :type unselected: bool
    '''

    pass


def lightmap_pack(PREF_CONTEXT: typing.Union[int, str] = 'SEL_FACES',
                  PREF_PACK_IN_ONE: bool = True,
                  PREF_NEW_UVLAYER: bool = False,
                  PREF_APPLY_IMAGE: bool = False,
                  PREF_IMG_PX_SIZE: int = 512,
                  PREF_BOX_DIV: int = 12,
                  PREF_MARGIN_DIV: float = 0.1):
    '''Pack each faces UV’s into the UV bounds 

    :param PREF_CONTEXT: SelectionSEL_FACES Selected Faces, Space all UVs evenly.ALL_FACES All Faces, Average space UVs edge length of each loop. 
    :type PREF_CONTEXT: typing.Union[int, str]
    :param PREF_PACK_IN_ONE: Share Tex Space, Objects Share texture space, map all objects into 1 uvmap 
    :type PREF_PACK_IN_ONE: bool
    :param PREF_NEW_UVLAYER: New UV Map, Create a new UV map for every mesh packed 
    :type PREF_NEW_UVLAYER: bool
    :param PREF_APPLY_IMAGE: New Image, Assign new images for every mesh (only one if shared tex space enabled) 
    :type PREF_APPLY_IMAGE: bool
    :param PREF_IMG_PX_SIZE: Image Size, Width and Height for the new image 
    :type PREF_IMG_PX_SIZE: int
    :param PREF_BOX_DIV: Pack Quality, Pre Packing before the complex boxpack 
    :type PREF_BOX_DIV: int
    :param PREF_MARGIN_DIV: Margin, Size of the margin as a division of the UV 
    :type PREF_MARGIN_DIV: float
    '''

    pass


def mark_seam(clear: bool = False):
    '''Mark selected UV edges as seams 

    :param clear: Clear Seams, Clear instead of marking seams 
    :type clear: bool
    '''

    pass


def minimize_stretch(fill_holes: bool = True,
                     blend: float = 0.0,
                     iterations: int = 0):
    '''Reduce UV stretching by relaxing angles 

    :param fill_holes: Fill Holes, Virtual fill holes in mesh before unwrapping, to better avoid overlaps and preserve symmetry 
    :type fill_holes: bool
    :param blend: Blend, Blend factor between stretch minimized and original 
    :type blend: float
    :param iterations: Iterations, Number of iterations to run, 0 is unlimited when run interactively 
    :type iterations: int
    '''

    pass


def pack_islands(rotate: bool = True, margin: float = 0.001):
    '''Transform all islands so that they fill up the UV space as much as possible 

    :param rotate: Rotate, Rotate islands for best fit 
    :type rotate: bool
    :param margin: Margin, Space between islands 
    :type margin: float
    '''

    pass


def pin(clear: bool = False):
    '''Set/clear selected UV vertices as anchored between multiple unwrap operations 

    :param clear: Clear, Clear pinning for the selection instead of setting it 
    :type clear: bool
    '''

    pass


def project_from_view(orthographic: bool = False,
                      camera_bounds: bool = True,
                      correct_aspect: bool = True,
                      clip_to_bounds: bool = False,
                      scale_to_bounds: bool = False):
    '''Project the UV vertices of the mesh as seen in current 3D view 

    :param orthographic: Orthographic, Use orthographic projection 
    :type orthographic: bool
    :param camera_bounds: Camera Bounds, Map UVs to the camera region taking resolution and aspect into account 
    :type camera_bounds: bool
    :param correct_aspect: Correct Aspect, Map UVs taking image aspect ratio into account 
    :type correct_aspect: bool
    :param clip_to_bounds: Clip to Bounds, Clip UV coordinates to bounds after unwrapping 
    :type clip_to_bounds: bool
    :param scale_to_bounds: Scale to Bounds, Scale UV coordinates to bounds after unwrapping 
    :type scale_to_bounds: bool
    '''

    pass


def remove_doubles(threshold: float = 0.02, use_unselected: bool = False):
    '''Selected UV vertices that are within a radius of each other are welded together 

    :param threshold: Merge Distance, Maximum distance between welded vertices 
    :type threshold: float
    :param use_unselected: Unselected, Merge selected to other unselected vertices 
    :type use_unselected: bool
    '''

    pass


def reset():
    '''Reset UV projection 

    '''

    pass


def reveal(select: bool = True):
    '''Reveal all hidden UV vertices 

    :param select: Select 
    :type select: bool
    '''

    pass


def seams_from_islands(mark_seams: bool = True, mark_sharp: bool = False):
    '''Set mesh seams according to island setup in the UV editor 

    :param mark_seams: Mark Seams, Mark boundary edges as seams 
    :type mark_seams: bool
    :param mark_sharp: Mark Sharp, Mark boundary edges as sharp 
    :type mark_sharp: bool
    '''

    pass


def select(extend: bool = False,
           deselect_all: bool = False,
           location: float = (0.0, 0.0)):
    '''Select UV vertices 

    :param extend: Extend, Extend selection rather than clearing the existing selection 
    :type extend: bool
    :param deselect_all: Deselect On Nothing, Deselect all when nothing under the cursor 
    :type deselect_all: bool
    :param location: Location, Mouse location in normalized coordinates, 0.0 to 1.0 is within the image bounds 
    :type location: float
    '''

    pass


def select_all(action: typing.Union[int, str] = 'TOGGLE'):
    '''Change selection of all UV vertices 

    :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
    :type action: typing.Union[int, str]
    '''

    pass


def select_box(pinned: bool = False,
               xmin: int = 0,
               xmax: int = 0,
               ymin: int = 0,
               ymax: int = 0,
               wait_for_input: bool = True,
               mode: typing.Union[int, str] = 'SET'):
    '''Select UV vertices using box selection 

    :param pinned: Pinned, Border select pinned UVs only 
    :type pinned: bool
    :param xmin: X Min 
    :type xmin: int
    :param xmax: X Max 
    :type xmax: int
    :param ymin: Y Min 
    :type ymin: int
    :param ymax: Y Max 
    :type ymax: int
    :param wait_for_input: Wait for Input 
    :type wait_for_input: bool
    :param mode: ModeSET Set, Set a new selection.ADD Extend, Extend existing selection.SUB Subtract, Subtract existing selection. 
    :type mode: typing.Union[int, str]
    '''

    pass


def select_circle(x: int = 0,
                  y: int = 0,
                  radius: int = 25,
                  wait_for_input: bool = True,
                  mode: typing.Union[int, str] = 'SET'):
    '''Select UV vertices using circle selection 

    :param x: X 
    :type x: int
    :param y: Y 
    :type y: int
    :param radius: Radius 
    :type radius: int
    :param wait_for_input: Wait for Input 
    :type wait_for_input: bool
    :param mode: ModeSET Set, Set a new selection.ADD Extend, Extend existing selection.SUB Subtract, Subtract existing selection. 
    :type mode: typing.Union[int, str]
    '''

    pass


def select_lasso(path: typing.List['bpy.types.OperatorMousePath'] = None,
                 mode: typing.Union[int, str] = 'SET'):
    '''Select UVs using lasso selection 

    :param path: Path 
    :type path: typing.List['bpy.types.OperatorMousePath']
    :param mode: ModeSET Set, Set a new selection.ADD Extend, Extend existing selection.SUB Subtract, Subtract existing selection. 
    :type mode: typing.Union[int, str]
    '''

    pass


def select_less():
    '''Deselect UV vertices at the boundary of each selection region 

    '''

    pass


def select_linked():
    '''Select all UV vertices linked to the active UV map 

    '''

    pass


def select_linked_pick(extend: bool = False,
                       deselect: bool = False,
                       location: float = (0.0, 0.0)):
    '''Select all UV vertices linked under the mouse 

    :param extend: Extend, Extend selection rather than clearing the existing selection 
    :type extend: bool
    :param deselect: Deselect, Deselect linked UV vertices rather than selecting them 
    :type deselect: bool
    :param location: Location, Mouse location in normalized coordinates, 0.0 to 1.0 is within the image bounds 
    :type location: float
    '''

    pass


def select_loop(extend: bool = False, location: float = (0.0, 0.0)):
    '''Select a loop of connected UV vertices 

    :param extend: Extend, Extend selection rather than clearing the existing selection 
    :type extend: bool
    :param location: Location, Mouse location in normalized coordinates, 0.0 to 1.0 is within the image bounds 
    :type location: float
    '''

    pass


def select_more():
    '''Select more UV vertices connected to initial selection 

    '''

    pass


def select_pinned():
    '''Select all pinned UV vertices 

    '''

    pass


def select_split():
    '''Select only entirely selected faces 

    '''

    pass


def smart_project(angle_limit: float = 66.0,
                  island_margin: float = 0.0,
                  user_area_weight: float = 0.0,
                  use_aspect: bool = True,
                  stretch_to_bounds: bool = True):
    '''This script projection unwraps the selected faces of a mesh (it operates on all selected mesh objects, and can be used to unwrap selected faces, or all faces) 

    :param angle_limit: Angle Limit, Lower for more projection groups, higher for less distortion 
    :type angle_limit: float
    :param island_margin: Island Margin, Margin to reduce bleed from adjacent islands 
    :type island_margin: float
    :param user_area_weight: Area Weight, Weight projections vector by faces with larger areas 
    :type user_area_weight: float
    :param use_aspect: Correct Aspect, Map UVs taking image aspect ratio into account 
    :type use_aspect: bool
    :param stretch_to_bounds: Stretch to UV Bounds, Stretch the final output to texture bounds 
    :type stretch_to_bounds: bool
    '''

    pass


def snap_cursor(target: typing.Union[int, str] = 'PIXELS'):
    '''Snap cursor to target type 

    :param target: Target, Target to snap the selected UVs to 
    :type target: typing.Union[int, str]
    '''

    pass


def snap_selected(target: typing.Union[int, str] = 'PIXELS'):
    '''Snap selected UV vertices to target type 

    :param target: Target, Target to snap the selected UVs to 
    :type target: typing.Union[int, str]
    '''

    pass


def sphere_project(direction: typing.Union[int, str] = 'VIEW_ON_EQUATOR',
                   align: typing.Union[int, str] = 'POLAR_ZX',
                   correct_aspect: bool = True,
                   clip_to_bounds: bool = False,
                   scale_to_bounds: bool = False):
    '''Project the UV vertices of the mesh over the curved surface of a sphere 

    :param direction: Direction, Direction of the sphere or cylinderVIEW_ON_EQUATOR View on Equator, 3D view is on the equator.VIEW_ON_POLES View on Poles, 3D view is on the poles.ALIGN_TO_OBJECT Align to Object, Align according to object transform. 
    :type direction: typing.Union[int, str]
    :param align: Align, How to determine rotation around the polePOLAR_ZX Polar ZX, Polar 0 is X.POLAR_ZY Polar ZY, Polar 0 is Y. 
    :type align: typing.Union[int, str]
    :param correct_aspect: Correct Aspect, Map UVs taking image aspect ratio into account 
    :type correct_aspect: bool
    :param clip_to_bounds: Clip to Bounds, Clip UV coordinates to bounds after unwrapping 
    :type clip_to_bounds: bool
    :param scale_to_bounds: Scale to Bounds, Scale UV coordinates to bounds after unwrapping 
    :type scale_to_bounds: bool
    '''

    pass


def stitch(use_limit: bool = False,
           snap_islands: bool = True,
           limit: float = 0.01,
           static_island: int = 0,
           active_object_index: int = 0,
           midpoint_snap: bool = False,
           clear_seams: bool = True,
           mode: typing.Union[int, str] = 'VERTEX',
           stored_mode: typing.Union[int, str] = 'VERTEX',
           selection: typing.List['bpy.types.SelectedUvElement'] = None,
           objects_selection_count: int = (0, 0, 0, 0, 0, 0)):
    '''Stitch selected UV vertices by proximity 

    :param use_limit: Use Limit, Stitch UVs within a specified limit distance 
    :type use_limit: bool
    :param snap_islands: Snap Islands, Snap islands together (on edge stitch mode, rotates the islands too) 
    :type snap_islands: bool
    :param limit: Limit, Limit distance in normalized coordinates 
    :type limit: float
    :param static_island: Static Island, Island that stays in place when stitching islands 
    :type static_island: int
    :param active_object_index: Active Object, Index of the active object 
    :type active_object_index: int
    :param midpoint_snap: Snap At Midpoint, UVs are stitched at midpoint instead of at static island 
    :type midpoint_snap: bool
    :param clear_seams: Clear Seams, Clear seams of stitched edges 
    :type clear_seams: bool
    :param mode: Operation Mode, Use vertex or edge stitching 
    :type mode: typing.Union[int, str]
    :param stored_mode: Stored Operation Mode, Use vertex or edge stitching 
    :type stored_mode: typing.Union[int, str]
    :param selection: Selection 
    :type selection: typing.List['bpy.types.SelectedUvElement']
    :param objects_selection_count: Objects Selection Count 
    :type objects_selection_count: int
    '''

    pass


def unwrap(method: typing.Union[int, str] = 'ANGLE_BASED',
           fill_holes: bool = True,
           correct_aspect: bool = True,
           use_subsurf_data: bool = False,
           margin: float = 0.001):
    '''Unwrap the mesh of the object being edited 

    :param method: Method, Unwrapping method (Angle Based usually gives better results than Conformal, while being somewhat slower) 
    :type method: typing.Union[int, str]
    :param fill_holes: Fill Holes, Virtual fill holes in mesh before unwrapping, to better avoid overlaps and preserve symmetry 
    :type fill_holes: bool
    :param correct_aspect: Correct Aspect, Map UVs taking image aspect ratio into account 
    :type correct_aspect: bool
    :param use_subsurf_data: Use Subsurf Modifier, Map UVs taking vertex position after Subdivision Surface modifier has been applied 
    :type use_subsurf_data: bool
    :param margin: Margin, Space between islands 
    :type margin: float
    '''

    pass


def weld():
    '''Weld selected UV vertices together 

    '''

    pass
